smartcard.wx.ReaderToolbar.ReaderToolbar

# ``smartcard`.`wx`.`ReaderToolbar`.`ReaderToolbar``

class documentation

`class ReaderToolbar(wx.ToolBar):`

View In Hierarchy

ReaderToolbar. Contains controls to select a reader from a listbox and connect to the cards.

Method | `__init__` | Constructor, creating the reader toolbar.
Instance Variable | `readercombobox` | Undocumented

def __init__(self, parent):

Constructor, creating the reader toolbar.

readercombobox =

Undocumented